@@ -14,12 +14,16 @@
 #define vec_t(Type) \
   struct { Type *d; size_t len, cap; }
 
-#define vec_init(v) \
-	memset((v), 0, sizeof(*(v)))
+#define vec_init() \
+	{ .d = NULL, .len = 0, .cap = 0 }
 
 #define vec_foreach(list, __i) \
 	for (size_t __i = 0; __i < (list).len; __i++)
 
+/* ssize_t because the value can be negative */
+#define vec_rforeach(list, __i) \
+	for (ssize_t __i = ((ssize_t)(list).len) -1 ; __i >= 0; __i--)
+
 #define vec_free(v) \
 	do { \
 		free((v)->d); \
@@ -55,7 +59,7 @@
 
 #define vec_push(v, _d)                                            \
 	do {                                                          \
-		if ((v)->len + 1 > (v)->cap) {                            \
+		if ((v)->len >= (v)->cap) {                            \
 			if ((v)->cap == 0)                              \
 				(v)->cap = 1;                          \
 			else                                          \
@@ -82,6 +86,35 @@
 #define vec_len(v) \
 	(v)->len
 
+#define DEFINE_VEC_INSERT_SORTED_PROTO(type, name, element_type) \
+	element_type *name##_insert_sorted(type *v, element_type el)
+
+#define DEFINE_VEC_INSERT_SORTED_FUNC(type, _name, element_type, compare_func) \
+	element_type *_name##_insert_sorted(type *v, element_type el) { \
+		/* Verify if the element already exists */ \
+		if (v->len > 0) { \
+			element_type *found = bsearch(&el, v->d, v->len, sizeof(element_type), compare_func); \
+			if (found != NULL){ \
+				return (found); \
+			} \
+		} \
+		if (v->len >= v->cap) { \
+			v->cap = (v->cap == 0) ? 1 : v->cap * 2; \
+			v->d = realloc(v->d, v->cap * sizeof(element_type)); \
+			if (v->d == NULL) \
+				abort(); \
+		} \
+		/* Find where to insert */ \
+		size_t i; \
+		for (i = v->len; i > 0 && compare_func(&v->d[i - 1], &el) > 0; i--) { \
+			v->d[i] = v->d[i - 1]; \
+		} \
+		v->d[i] = el; \
+		v->len++; \
+		return (NULL); \
+	}
+
 typedef vec_t(char *) charv_t;
 typedef vec_t(const char *) c_charv_t;
+
 #endif
