@@ -447,8 +447,8 @@ pkg_cleanup_shlibs_required(struct pkg *pkg, charv_t *internal_provided)
 
 	vec_foreach(pkg->shlibs_required, i) {
 		const char *s = pkg->shlibs_required.d[i];
-		if (charv_contains(&pkg->shlibs_provided, s, false) ||
-		    charv_contains(internal_provided, s, false)) {
+		if (charv_search(&pkg->shlibs_provided, s) != NULL ||
+		    charv_search(internal_provided, s) != NULL) {
 			pkg_debug(2,
 			    "remove %s from required shlibs as the "
 			    "package %s provides this library itself",
@@ -530,11 +530,9 @@ pkg_analyse_files(struct pkgdb *db __unused, struct pkg *pkg, const char *stage)
 	/* shlibs that are provided by files in the package but not matched by
 	   SHLIB_PROVIDE_PATHS_* are still used to filter the shlibs
 	   required by the package */
-	charv_t internal_provided;
-	vec_init(&internal_provided);
+	charv_t internal_provided = vec_init();
 	/* list of shlibs that are in the path to be evaluated for provided but are symlinks */
-	charv_t maybe_provided;
-	vec_init(&maybe_provided);
+	charv_t maybe_provided = vec_init();
 
 	while (pkg_files(pkg, &file) == EPKG_OK) {
 		struct stat st;
