@@ -68,9 +68,8 @@ pkg_create_from_dir(struct pkg *pkg, const char *root,
 	const char	*relocation;
 	char		*manifest;
 	ucl_object_t	*obj;
-	hardlinks_t	 hardlinks;
+	hardlinks_t	 hardlinks = vec_init();
 
-	vec_init(&hardlinks);
 	if (pkg_is_valid(pkg) != EPKG_OK) {
 		pkg_emit_error("the package is not valid");
 		return (EPKG_FATAL);
@@ -501,6 +500,7 @@ load_metadata(struct pkg *pkg, const char *metadata, const char *plist,
 	}
 
 	if ((pkg_parse_manifest_fileat(fd, pkg, "+MANIFEST")) != EPKG_OK) {
+		pkg_emit_error("Error parsing %s/+MANIFEST", metadata);
 		close(fd);
 		return (EPKG_FATAL);
 	}
