@@ -832,6 +832,16 @@ pkgdb_open(struct pkgdb **db_p, pkgdb_t type)
 	return (pkgdb_open_all(db_p, type, NULL));
 }
 
+/* the higher the better */
+static int
+repos_prio_cmp(const void *a, const void *b)
+{
+	struct pkg_repo *ra = *(struct pkg_repo **)a;
+	struct pkg_repo *rb = *(struct pkg_repo **)b;
+
+	return ((ra->priority < rb->priority) - (ra->priority > rb->priority));
+}
+
 static int
 pkgdb_open_repos(struct pkgdb *db, const char *reponame)
 {
@@ -852,6 +862,7 @@ pkgdb_open_repos(struct pkgdb *db, const char *reponame)
 				    " 'pkg update' required", r->name);
 		}
 	}
+	qsort(db->repos.d, db->repos.len, sizeof(db->repos.d[0]), repos_prio_cmp);
 
 	return (EPKG_OK);
 }
@@ -992,10 +1003,9 @@ pkgdb_nfs_corruption(sqlite3 *db)
 int
 pkgdb_open_all(struct pkgdb **db_p, pkgdb_t type, const char *reponame)
 {
-	c_charv_t r;
+	c_charv_t r = vec_init();
 	int ret;
 
-	vec_init(&r);
 	if (reponame != NULL)
 		vec_push(&r, reponame);
 
@@ -1177,20 +1187,20 @@ pkgdb_close(struct pkgdb *db)
 static int
 run_transaction(sqlite3 *sqlite, const char *query, const char *savepoint)
 {
-	int		 ret;
+	int		 ret = SQLITE_OK;
 	sqlite3_stmt	*stmt;
 	char *sql = NULL;
 
 	assert(sqlite != NULL);
 
 	xasprintf(&sql, "%s %s", query, savepoint != NULL ? savepoint : "");
-	ret = sqlite3_prepare_v2(sqlite, sql, strlen(sql) + 1, &stmt, NULL);
+	stmt = prepare_sql(sqlite, sql);
+	if (stmt == NULL)
+		return (EPKG_FATAL);
 	pkgdb_debug(4, stmt);
 
-	if (ret == SQLITE_OK) {
-		PKGDB_SQLITE_RETRY_ON_BUSY(ret)
-			ret = sqlite3_step(stmt);
-	}
+	PKGDB_SQLITE_RETRY_ON_BUSY(ret)
+		ret = sqlite3_step(stmt);
 
 	if (ret != SQLITE_OK && ret != SQLITE_DONE) {
 		ERROR_STMT_SQLITE(sqlite, stmt);
@@ -1817,7 +1827,7 @@ pkgdb_register_pkg(struct pkgdb *db, struct pkg *pkg, int forced,
 			goto cleanup;
 		}
 		if ((ret = run_prstmt(DIRS2, package_id, dir->path,
-		    true)) != SQLITE_DONE) {
+		    (int64_t)true)) != SQLITE_DONE) {
 			if (ret == SQLITE_CONSTRAINT) {
 				pkg_emit_error("Another package is already "
 				    "providing directory: %s",
@@ -2636,6 +2646,7 @@ pkgdb_check_lock_pid(struct pkgdb *db)
 			}
 		}
 	}
+	sqlite3_finalize(stmt);
 
 	if (found == 0)
 		return (EPKG_END);
@@ -2923,11 +2934,10 @@ pkgdb_begin_solver(struct pkgdb *db)
 		"CREATE INDEX pkg_digest_id ON packages(name, manifestdigest);";
 	struct pkgdb_it *it;
 	struct pkg *p = NULL;
-	pkgs_t pkglist;
+	pkgs_t pkglist = vec_init();
 	int rc = EPKG_OK;
 	int64_t cnt = 0, cur = 0;
 
-	vec_init(&pkglist);
 	it = pkgdb_query_cond(db, " WHERE manifestdigest IS NULL OR manifestdigest==''",
 		NULL, MATCH_ALL);
 	if (it != NULL) {
